==> openshift-client-4.11.1-sources.jar: io/fabric8/openshift/client/dsl/internal/ServiceCAOperationsImpl.java <==

                
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.DoneableServiceCA;
import io.fabric8.openshift.api.model.operator.v1.ServiceCA;
import io.fabric8.openshift.api.model.operator.v1.ServiceCAList;
import io.fabric8.openshift.api.model.operator.v1.DoneableServiceCA;

import java.util.Map;
import java.util.TreeMap;


public class ServiceCAOperationsImpl extends OpenShiftOperation<ServiceCA, ServiceCAList, DoneableServiceCA, Resource<ServiceCA, DoneableServiceCA>> {

  public ServiceCAOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ServiceCAOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("servicecas"));
    this.type = ServiceCA.class;
    this.listType = ServiceCAList.class;
    this.doneableType = DoneableServiceCA.class;
  }

  public ServiceCAOperationsImpl newInstance(OperationContext context) {
    return new ServiceCAOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> openshift-client-5.3.0-sources.jar: io/fabric8/openshift/client/dsl/internal/ServiceCAOperationsImpl.java <==

                            
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.ServiceCA;
import io.fabric8.openshift.api.model.operator.v1.ServiceCABuilder;
import io.fabric8.openshift.api.model.operator.v1.ServiceCAList;

import java.util.Map;
import java.util.TreeMap;


public class ServiceCAOperationsImpl extends OpenShiftOperation<ServiceCA, ServiceCAList, Resource<ServiceCA>> {

  public ServiceCAOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ServiceCAOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("servicecas"));
    this.type = ServiceCA.class;
    this.listType = ServiceCAList.class;
  }

  public ServiceCAOperationsImpl newInstance(OperationContext context) {
    return new ServiceCAOperationsImpl(context);
  }

  @Override
  public ServiceCA edit(Visitor... visitors) {
    return patch(new ServiceCABuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
